==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/KafkaX509AuthenticationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.KafkaX509AuthenticationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Kafka RemoteBrokerConnection X509 Authentication properties.
 * @property keyVault Keyvault X509 secret properties.
 * @property secretName Secret where cert details are stored.
 */
public data class KafkaX509AuthenticationArgs(
    public val keyVault: Output<KeyVaultCertificatePropertiesArgs>? = null,
    public val secretName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.KafkaX509AuthenticationArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.KafkaX509AuthenticationArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.KafkaX509AuthenticationArgs.builder()
            .keyVault(keyVault?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .secretName(secretName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KafkaX509AuthenticationArgs].
 */
@PulumiTagMarker
public class KafkaX509AuthenticationArgsBuilder internal constructor() {
    private var keyVault: Output<KeyVaultCertificatePropertiesArgs>? = null

    private var secretName: Output<String>? = null

    /**
     * @param value Keyvault X509 secret properties.
     */
    @JvmName("vyxgiuqwdrnknvib")
    public suspend fun keyVault(`value`: Output<KeyVaultCertificatePropertiesArgs>) {
        this.keyVault = value
    }

    /**
     * @param value Secret where cert details are stored.
     */
    @JvmName("ktrmnotqplraykft")
    public suspend fun secretName(`value`: Output<String>) {
        this.secretName = value
    }

    /**
     * @param value Keyvault X509 secret properties.
     */
    @JvmName("xbxbsmpdvojqhnfr")
    public suspend fun keyVault(`value`: KeyVaultCertificatePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVault = mapped
    }

    /**
     * @param argument Keyvault X509 secret properties.
     */
    @JvmName("iyainglubmgoehvn")
    public suspend
    fun keyVault(argument: suspend KeyVaultCertificatePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = KeyVaultCertificatePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.keyVault = mapped
    }

    /**
     * @param value Secret where cert details are stored.
     */
    @JvmName("nndnmjtgafrceyxb")
    public suspend fun secretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretName = mapped
    }

    internal fun build(): KafkaX509AuthenticationArgs = KafkaX509AuthenticationArgs(
        keyVault = keyVault,
        secretName = secretName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/KafkaX509AuthenticationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.KafkaX509AuthenticationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Kafka RemoteBrokerConnection X509 Authentication properties.
 * @property keyVault Keyvault X509 secret properties.
 * @property secretName Secret where cert details are stored.
 */
public data class KafkaX509AuthenticationArgs(
    public val keyVault: Output<KeyVaultCertificatePropertiesArgs>? = null,
    public val secretName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.KafkaX509AuthenticationArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.KafkaX509AuthenticationArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.KafkaX509AuthenticationArgs.builder()
            .keyVault(keyVault?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .secretName(secretName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KafkaX509AuthenticationArgs].
 */
@PulumiTagMarker
public class KafkaX509AuthenticationArgsBuilder internal constructor() {
    private var keyVault: Output<KeyVaultCertificatePropertiesArgs>? = null

    private var secretName: Output<String>? = null

    /**
     * @param value Keyvault X509 secret properties.
     */
    @JvmName("oyplrguvuoffsoov")
    public suspend fun keyVault(`value`: Output<KeyVaultCertificatePropertiesArgs>) {
        this.keyVault = value
    }

    /**
     * @param value Secret where cert details are stored.
     */
    @JvmName("chjxnktrmfmyuhec")
    public suspend fun secretName(`value`: Output<String>) {
        this.secretName = value
    }

    /**
     * @param value Keyvault X509 secret properties.
     */
    @JvmName("wqjnxoxwusspaqld")
    public suspend fun keyVault(`value`: KeyVaultCertificatePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVault = mapped
    }

    /**
     * @param argument Keyvault X509 secret properties.
     */
    @JvmName("ynxiikftxsxjsqap")
    public suspend
    fun keyVault(argument: suspend KeyVaultCertificatePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = KeyVaultCertificatePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.keyVault = mapped
    }

    /**
     * @param value Secret where cert details are stored.
     */
    @JvmName("udcabelnvddwdglj")
    public suspend fun secretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretName = mapped
    }

    internal fun build(): KafkaX509AuthenticationArgs = KafkaX509AuthenticationArgs(
        keyVault = keyVault,
        secretName = secretName,
    )
}
